@@ -4,13 +4,16 @@
 #pragma once
 
 #define RTC_VERSION_MAJOR 3
-#define RTC_VERSION_MINOR 10
+#define RTC_VERSION_MINOR 11
 #define RTC_VERSION_PATCH 0
-#define RTC_VERSION 31000
-#define RTC_VERSION_STRING "3.10.0"
+#define RTC_VERSION 31100
+#define RTC_VERSION_STRING "3.11.0"
 
 #define RTC_MAX_INSTANCE_LEVEL_COUNT 1
 
+#define EMBREE_MIN_WIDTH 0
+#define RTC_MIN_WIDTH EMBREE_MIN_WIDTH
+
 /* #undef EMBREE_STATIC_LIB */
 /* #undef EMBREE_API_NAMESPACE */
 
